#
# spec file for package coccigrep
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           coccigrep
Version:        1.20
Release:        4.3
Summary:        Semantic grep tool for C, based on coccinelle
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/regit/coccigrep
Source:         https://github.com/regit/coccigrep/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  xz
Requires:       coccinelle
Requires:       python3
# Mimicing coccinelle
ExclusiveArch:  aarch64 ppc64le powerpc64le s390x x86_64 riscv64
BuildArch:      noarch

%description
coccigrep is a semantic grep for the C language based on coccinelle. It can be
used to find where a given structure is used in code files. coccigrep depends on
the spatch program which comes with coccinelle.

%prep
%setup -q
chmod 644 README.rst

%build
%python3_build

%install
%python3_install

install -d %{buildroot}/%{_mandir}/man1/
install -m 644 coccigrep.1 %{buildroot}/%{_mandir}/man1/

%files
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/*
%{_bindir}/coccigrep
%{_mandir}/man1/coccigrep.1%{?ext_man}

%changelog
* Tue Apr 11 2023 Andreas Schwab <schwab@suse.de>
- Update ExclusiveArch list
* Wed Apr  6 2022 Jiri Slaby <jslaby@suse.cz>
- Use python build macros
* Wed Mar 30 2022 Jiri Slaby <jslaby@suse.cz>
- Use ExclusiveArch the same as coccinelle
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.20:
  - Fix a python3 comptability issue
  - Add grep color mode
  - Fix multiple matches on one line
  - This release fixes #19 and improve matching capabilities
  - Address a issue with pygments installation on Python 2 and fix parallel execution
  - Some light fixes on the documentation and a cleaner setup.py so the project looks decent on Pypi.
* Mon Jun 18 2018 opensuse-packaging@opensuse.org
- Update to version 1.17+git.20180322:
  * grep mode: fix multiline case
  * fix typo in comment
  * used: fix equality match
  * allow multiple match on the same line
  * fix grep mode display
  * Update version to 1.17
  * set only color in grep mode for tty
  * color attribute in grep mode
  * add grep mode for color
* Mon Oct 31 2016 jslaby@suse.com
- package also LICENSE
* Mon Oct 31 2016 jslaby@suse.com
- Update to version 20160815:
  * forcing a type to be present was arbitrary
  * vim plugin: fix interactive mode
  * document void option usage in vim plugin
  * Add python3 support
  * Add support for python 3.4
  * setup: use and complete install_requires
  * Fix syntax error in python3 environment.
* Thu Jan 15 2015 jslaby@suse.com
- update to 20150112
  * python3 support added
- clean up .spec
  * switch to python3
* Mon Sep 15 2014 jslaby@suse.com
- update to latest snapshot (20140913)
  * see ChangeLog for changes
* Wed Jul  2 2014 jslaby@suse.com
- update to latest snapshot (20140217)
  * see ChangeLog for changes
* Sat Aug 17 2013 jslaby@suse.com
- update to latest snapshot (20130723)
  * see ChangeLog for changes
* Mon Dec 31 2012 jslaby@suse.com
- update to latest snapshot (20121222)
  * see ChangeLog for changes
* Wed Sep 12 2012 jslaby@suse.com
- update to latest snapshot (1347289051)
  * see ChangeLog for changes
* Tue Aug 21 2012 jslaby@suse.de
- initial package
